PcapWriter

Struct PcapWriter 

pub struct PcapWriter<W: Write> { /* private fields */ }
The PcapReader struct allows reading packets from a packet capture.

Implementations

Source

impl<W: Write> PcapWriter<W>

pub fn new(writer: W, opts: WriteOptions) -> Result<Self, PcapError>

Create a new PcapWriter that writes the packet capture data to the specified Write.

pub fn append_unchecked( writer: W, opts: WriteOptions, ) -> Result<Self, PcapError>

Create a new PcapWriter that appends the packets to an existing Write. If the WriteOptions specified here are different than those used to create the file, the resulting file will be invalid.

Warning: Only append to created using PcapWriter::new on the same machine. Files created on other architectures or from another tool/library might use different timestamp formats or endianness, leading to data corruption.

pub fn append(stream: W) -> Result<Self, PcapError>
where W: Read + Seek,

Create a new PcapWriter that appends the packets to an existing stream, which must support Read + Write + Seek so that the correct format options for the file can be determined.

pub fn write(&mut self, packet: &CapturedPacket<'_>) -> Result<(), PcapError>

Write a package to the capture file.

pub fn flush(&mut self) -> Result<(), Error>

Flushes the underlying writer.

pub fn take_writer(self) -> W

Destroys this PcapWriter and returns access to the underlying Write.

pub fn get_options(&self) -> WriteOptions

The options used by this PcapWriter.